import Input from 'antd/lib/input'
import BigNumber from 'bignumber.js'
import React, { ChangeEvent, useState, useEffect } from 'react'
import './index.scss'

interface MoneyInputProps {
  maxPrice?: number
  minPrice?: number
  value?: string
  digitLimit?: number
  onChange?: (value: string) => void
  // setValue: (val: string | null) => void
}
const MoneyInput: React.FC<MoneyInputProps> = (props) => {
  const { minPrice, maxPrice, onChange, digitLimit = 2 } = props
  const value = props.value ? props.value.toString() : ''

  // const reg = new RegExp("^(\d*)\.?(\d{0," + digitLimit + "})")
  const [ inputVal, setInputVal ] = useState('')

  const [ digit, setDigit ] = useState<number | null>(null)

  const triggerChange = (changedValue: string) => {
    onChange && onChange(changedValue)
  }

  const digits = {
    4: '千',
    5: '万',
    6: '十万',
    7: '百万',
    8: '千万',
    9: '亿',
    10: '十亿',
    11: '百亿',
    12: '千亿'
  }

  useEffect(() => {
    if (value) {
      const len = value.match(/^(\d*)\.?(\d{0,2})/)
      len && setDigit(digits[parseFloat(len[1]).toString().length])
    }
  }, [ value ])


  const changeDigitMap = (len: number | null) => {
    if (len && digits[len]) {
      setDigit(digits[len])
    } else {
      setDigit(null)
    }
  }
  const handleChange = (e: ChangeEvent<HTMLInputElement>) => {
    const val = e.target.value?.match(/^(\d*)\.?(\d{0,2})/)

    const newInputVal = val && val[0] || ''

    // console.log(val);
    
    // if (newInputVal) {
    //   newInputVal = new BigNumber(newInputVal).toString()
    // }
    if (newInputVal) {
      // newInputVal = parseFloat(newInputVal).toString()
      // if (maxPrice && parseFloat(newInputVal) > maxPrice) {
      //   newInputVal = maxPrice.toString()
      // }

      // if (minPrice && parseFloat(newInputVal) < minPrice) {
      //   console.log(minPrice)

      //   newInputVal = minPrice.toString()
      // }
      const len = val && val[1] && new BigNumber(val[1]).toString().length || null

      if (len && len > 12) {
        return
      }
      if (len && digits[len]) {
        changeDigitMap(len)
      } else {
        changeDigitMap(null)
      }
    }

    if (!newInputVal) {
      setInputVal('')
    }
    triggerChange(newInputVal)
  }

  return (
    <div className='ant-input ant-input-sm'>
      <div className="pi-flex-row">
        <span className="pi-fz-14 pi-mg-right-5">￥</span>
        <Input bordered={false} value={inputVal || value} size="small" onChange={handleChange} autoComplete="off" />
      </div>
      {
        digit ?
          <div className='line-separator'>
            <div className="side-line"> </div>
            <div className="triangle-triangle" />
            <div className="triangle-num">{digit}</div>
            <div className="side-line"> </div>
          </div>
          : null
      }
    </div>
  )
}

export default MoneyInput
