import React, { useState } from 'react'
import Header from '@/components/Header'
import { Button, Form, Input, message } from 'antd'
import styles from './index.module.scss'
import consts from '@/utils/consts'
import { apiChangePassword } from './api'
import StrengthMeter from '@/components/StrengthMeter'

export default function Index() {
  const [ form ] = Form.useForm()
  const [ loading, setLoading ] = useState<boolean>(false)
  // const [ score, setScore ] = useState<number>(0)
  // 保存表单信息
  const changePassword = async (values: any) => {
    setLoading(true)
    const { code = -1 } = await apiChangePassword(values)
    if (code === consts.RET_CODE.SUCCESS) {
      message.success("更新成功")
    }
    setLoading(false)
  }

  return (
    <div className="wrap-contaniner">
      <Header title="账号安全" />
      <div className={styles.projectInfo}>
        <Form form={form} className={styles.formContent} layout="vertical" size="small">
          <Form.Item name="password" label="原密码" rules={[ { required: true, message: '请输入原密码' } ]}>
            <Input.Password />
          </Form.Item>
          <Form.Item name="newPassword" label="新密码" rules={[ { required: true, message: '请输入新密码' }, () => ({
            validator(_, value: string) {
              // setScore(pswRef && pswRef.current?.state.value ? zxcvbn(pswRef.current.state.value, []).score : 0)
              if (!value) return Promise.resolve()
              if (/(?=.*[0-9])(?=.*[a-zA-Z]).{6,30}/.test(value)) {
                return Promise.resolve()
              } else {
                return Promise.reject('密码必须带有字母与数字的组合且大于或等于6位')
              }
            }
          }) ]}>
            <StrengthMeter />
          </Form.Item>
          <Form.Item name="confirmPassword" label="确认新密码" rules={[ { required: true, message: '请输入确认新密码' }, ({ getFieldValue }) => ({
            validator(_, value) {
              if (getFieldValue('newPassword') !== value) {
                return Promise.reject('密码不一致')
              }
              return Promise.resolve()
            }
          }) ]}>
            <Input.Password />
          </Form.Item>

          <Button type="primary" size="small" loading={loading} onClick={() => {
            form.validateFields().then(values => {
              changePassword(values)
            })
          }}>保存修改</Button>
        </Form>
      </div>
    </div>
  )
}
