import request from '@/utils/common/request'

enum ContractType {
  income = 'return',
  expenditure = 'paid'
}

/**
 * 删除回款(收入/支出)
 * @param id 回款id
 * @param contractsId 合同id
 * @param bidsectionId 标段id
 */
export async function apiDelReturn(contractType: 'income' | 'expenditure', id: string, contractsId: string, bidsectionId: string) {
  const { data } = await request.del(`/api/contract/${ContractType[contractType]}/delete`, { id, contractsId, bidsectionId })
  return data
}

/**
 * 获取合同回款列表(收入/支出)
 * @param constractsId 合同id
 * @param bidsectionId 标段id
 */
export async function apiGetReturns(contractType: 'income' | 'expenditure', contractsId: string, bidsectionId: string) {
  const { data } = await request.get(`/api/contract/${ContractType[contractType]}/list`, { contractsId, bidsectionId, page: 1 })
  return data
}

/**
 * 获取回款类型
 */
export async function apiGetReturnWay() {
  const { data } = await request.get('/api/contract/return/way')
  return data
}

/**
 * 更新回款内容(收入/支出)
 * @param payload 载荷
 */
export async function apiUpdateReturn(contractType: 'income' | 'expenditure', payload: object) {
  const { data } = await request.post(`/api/contract/${ContractType[contractType]}/update`, payload)
  return data
}
