import React, { memo } from 'react'
import './index.scss'
import { Pie, G2, DualAxes } from '@ant-design/charts'
import { PieConfig, DualAxesConfig } from '@ant-design/charts'
import './index.scss'
import { formatMoney } from '@/utils/util'
import { Tooltip } from 'antd'
import BigNumber from 'bignumber.js'
import { ContractType } from '@/store/mobx/contract'
G2.registerTheme('custom-pie', {
  colors10: [ '#C7B8A1', '#9CA8B8', '#7B8B6F' ],
  colors29: [ '#DACAB1', '#ABB8CA', '#87987A' ]
})

interface iContentPieState {
  type: string
  value: number
}

interface iContentData {
  progress: number
  pieData: iContentPieState[]
  returnDate: iDualAxes
  totalContractPrice: number
  totalContractPriceShow: number
  totalReturnPriceShow?: number
  totalPaidPriceShow?: number
  unTotalReturnPriceShow?: number
  unTotalPaidPriceShow?: number
}

type iDualAxes = {
  month: string
  value: number
  count: BigNumber.Value
}[]
interface iContentProps {
  data: iContentData
  type: 'expenditure' | 'income'
}
const Content: React.FC<iContentProps> = ({ data, type }) => {

  const pieConfig: PieConfig = {
    data: data.pieData,
    autoFit: true,
    padding: 40,
    angleField: 'value',
    colorField: 'type',
    radius: 1,
    innerRadius: 0.7,
    label: {
      type: 'inner',
      offset: '-50%',
      style: { textAlign: 'center' },
      autoRotate: false,
      content: '{value}'
    },

    interactions: [ { type: 'element-selected' }, { type: 'element-active' } ],
    legend: {
      layout: 'horizontal',
      position: 'top'
    },
    theme: 'custom-pie'
  }

  const dualAxesConfig: DualAxesConfig = {
    data: [ data.returnDate, data.returnDate ],
    padding: 'auto',
    xField: 'month',
    yField: [ 'value', 'count' ],
    // slider: {},
    limitInPlot: false,
    // padding: [ 20, 20, 60, 30 ],
    meta: {
      month: {
        sync: false
      }
    },
    // xAxis: {
    //   label: {
    //     formatter: (val) => dayjsFormat(val, 'YYYY年M月')
    //   }
    // },
    yAxis: {
      value: {
        label: {
          formatter: (val) => `${val}元`
        }
      },
      count: {
        label: {
          formatter: (val) => `${val}%`
        }
      }
    },
    tooltip: {
      formatter: datum => {
        const obj = { name: '', value: formatMoney(datum.value) }
        if (datum.count || datum.count === 0) {
          obj.name = '占总金额比例'
          obj.value = (isNaN(datum.count) ? 0 : datum.count) + '%'
          return obj
        }
        if (type === ContractType.INCOME) {
          obj.name = '回款金额'
        } else {
          obj.name = '支付金额'
        }
        return obj
      }
    },
    geometryOptions: [
      {
        geometry: 'column',
        columnWidthRatio: 0.4,
        color: type === ContractType.INCOME ? '#B5C4B1' : '#A27E7E'
      },
      {
        geometry: 'line',
        color: type === ContractType.INCOME ? '#965454' : '#8C8C8C'
        // seriesField: 'count',
        // isPercent: true
        // smooth: true
      }
    ],

    legend: {
      position: 'top',
      itemName: {
        formatter: (text: string) => {
          if (text === 'value') {
            return type === ContractType.INCOME ? '回款金额' : '支付金额'
          }
          return '占总金额比例'
        }
      }
    }
    // legend: {
    //   custom: true,
    //   position: 'top',
    //   items: [
    //     {
    //       value: 'value',
    //       name: '回款金额',
    //       marker: { symbol: 'square', style: { fill: type === ContractType.INCOME ? '#B5C4B1' : '#A27E7E', r: 5 } }
    //     },
    //     {
    //       value: 'count',
    //       name: '占总金额比例',
    //       marker: { symbol: 'line', style: { fill: type === ContractType.INCOME ? '#965454' : '#8C8C8C' } }
    //     }
    //   ]
    // }
  }


  return (
    <div className="pi-flex-column ">
      <div className="card-body card-border">
        <h5 className="card-title">{type === ContractType.INCOME ? '收入' : '支出'}合同结算进度</h5>
          <div className="progress-content">
            <Tooltip title={type === ContractType.INCOME ? ('已回款: ￥' + formatMoney(data.totalReturnPriceShow)): ('已支付: ￥' + formatMoney(data.totalPaidPriceShow))}>
              <div className={[ "progress-bar", type === ContractType.INCOME ? 'pi-bg-success' : 'pi-bg-red' ].join(' ')} style={{ width: data.progress + '%' }}>
                {data.progress}%
              </div>
            </Tooltip>
            <Tooltip title={type === ContractType.INCOME ? ('未回款：￥' + formatMoney(data.unTotalReturnPriceShow)) : ('未支付：￥' + formatMoney(data.unTotalPaidPriceShow))}>
              <div className="progress-bar pi-bg-gray" style={{ width: (100 - data.progress) + '%' }} >
                {parseFloat(new BigNumber(100).minus(data.progress).toFixed(2))}%
              </div>
            </Tooltip>
          </div>
      </div>
      <div className="pi-justify-between mb-3 mt-3">
        <div className="pi-flex-sub pi-mg-right-15 card-border pi-mg-right-15">
          <Pie {...pieConfig} />
        </div>
        <div className="pi-flex-sub pi-mg-left-15 pi-mg-left-15">
          <div className="pi-flex-column pi-justify-between">
            <div className="card-body card-border pi-flex-column pi-justify-between">
              <h5 className="card-title">{formatMoney(data.totalContractPrice)}</h5>
              <span className="pi-text-center">{type === ContractType.INCOME ? '收入' : '支出'}合同金额</span>
            </div>
            <div className="card-body card-border pi-flex-column pi-mg-tb-15">
              <h5 className="card-title">{formatMoney(parseFloat(new BigNumber(data.totalContractPriceShow).minus(type === ContractType.INCOME ? data.totalReturnPriceShow || 0 : data.totalPaidPriceShow || 0).toFixed(2)))}</h5>
              <span className="pi-text-center">{type === ContractType.INCOME ? '未回款' : '未支付'}</span>
            </div>
            <div className="card-body card-border pi-flex-column">
              <h5 className="card-title">{formatMoney(type === ContractType.INCOME ? data.totalReturnPriceShow : data.totalPaidPriceShow)}</h5>
              <span className="pi-text-center">{type === ContractType.INCOME ? '已回款' : '已支付'}</span>
            </div>
          </div>
        </div>
      </div>
      <div className="card-body card-border dual-axes-content">
        {/* <h5>{type === ContractType.INCOME ? '收入' : '支出'}合同结算趋势</h5> */}
        <DualAxes {...dualAxesConfig} />
      </div>
    </div>
  )
}

export default memo(Content)
