import Header from '@/components/Header'
import { tenderStore } from '@/store/mobx'
import consts from '@/utils/consts'
import React, { useEffect, useState, useMemo } from 'react'
import { apiGetContractSurvey } from './api'
import Content from './components/Content'
import './index.scss'
import { BigNumber } from 'bignumber.js'
type ireturnDate = {
  [key: string]: number
}
interface iBaseState {
  closeNumber: number
  performNumber: number
  returnDate: ireturnDate
  totalContractPrice: number
  totalContractPriceShow: number
  uncloseNumber: number
}
interface iExpenditureState extends iBaseState {
  totalPaidPriceShow: number
}

interface iIncomeState extends iBaseState {
  totalReturnPriceShow: number
}

interface iContractSummaryState {
  expenditureData: iExpenditureState
  incomeData: iIncomeState
}

export default function Summary() {
  useEffect(() => {
    initData()
  }, [])

  const [ state, setState ] = useState<iContractSummaryState>({
    expenditureData: {
      closeNumber: 0,
      performNumber: 0,
      returnDate: {},
      totalContractPrice: 0,
      totalContractPriceShow: 0,
      totalPaidPriceShow: 0,
      uncloseNumber: 0
    },
    incomeData: {
      closeNumber: 0,
      performNumber: 0,
      returnDate: {},
      totalContractPrice: 0,
      totalContractPriceShow: 0,
      totalReturnPriceShow: 0,
      uncloseNumber: 0
    }
  })
  const initData = async () => {
    const { code = -1, data } = await apiGetContractSurvey(tenderStore.bid)
    if (code === consts.RET_CODE.SUCCESS) {
      setState({ ...state, ...data })
    }
  }

  const expenditurePieData = useMemo(() => {
    const { closeNumber, performNumber, uncloseNumber,  totalContractPrice, totalContractPriceShow, totalPaidPriceShow, returnDate  } = state.expenditureData
    const pieData = [
      {
        type: '正常关闭',
        value: closeNumber
      },
      {
        type: '履行中',
        value: performNumber
      },
      {
        type: '待关闭',
        value: uncloseNumber
      }
    ]
    const dualAxes = []
    for (const key in returnDate) {
      if (Object.prototype.hasOwnProperty.call(returnDate, key)) {
        const value = returnDate[key]
        dualAxes.push({ month: key, value })
      }
    }

    const newDualAxes = dualAxes.map(item => {
      const isNan = new BigNumber(item.value).dividedBy(totalContractPrice).multipliedBy(100).isNaN()
      return { ...item, count: isNan ? 0 : parseFloat(new BigNumber(item.value).dividedBy(totalContractPrice).multipliedBy(100).toFixed(2)) }
    })


    let progress = parseFloat(new BigNumber(totalPaidPriceShow).dividedBy(totalContractPrice).multipliedBy(100).toFixed(2))

    const unTotalPaidPriceShow = parseFloat(new BigNumber(totalContractPrice).minus(totalPaidPriceShow).toFixed(2))

    isNaN(progress) && (progress = 0)
    return { pieData, returnDate: newDualAxes, totalContractPrice, totalContractPriceShow, totalPaidPriceShow, unTotalPaidPriceShow, progress }
  }, [ state.expenditureData ])


  const incomePieData = useMemo(() => {
    const { closeNumber, performNumber, uncloseNumber, returnDate, totalContractPrice, totalContractPriceShow, totalReturnPriceShow } = state.incomeData

    const pieData = [
      {
        type: '正常关闭',
        value: closeNumber
      },
      {
        type: '履行中',
        value: performNumber
      },
      {
        type: '待关闭',
        value: uncloseNumber
      }
    ]

    const dualAxes = []
    for (const key in returnDate) {
      if (Object.prototype.hasOwnProperty.call(returnDate, key)) {
        const value = returnDate[key] as number
        dualAxes.push({ month: key, value })
      }
    }
    const newDualAxes = dualAxes.map(item => {
      const isNan = new BigNumber(item.value).dividedBy(totalContractPrice).multipliedBy(100).isNaN()
      return { ...item, count: isNan ? 0 : parseFloat(new BigNumber(item.value).dividedBy(totalContractPrice).multipliedBy(100).toFixed(2)) }
    })

    let progress = parseFloat(new BigNumber(totalReturnPriceShow).dividedBy(totalContractPrice).multipliedBy(100).toFixed(2))
    isNaN(progress) && (progress = 0)

    const unTotalReturnPriceShow = parseFloat(new BigNumber(totalContractPrice).minus(totalReturnPriceShow).toFixed(2))


    return { pieData, returnDate: newDualAxes, totalContractPrice, totalContractPriceShow, totalReturnPriceShow, unTotalReturnPriceShow, progress }
  }, [ state.incomeData ])
  return (
    <div className="wrap-contaniner">
      <Header title="合同概况" />
      <div className="wrap-content scroll p-3 pi-grid pi-col-2 pi-col-space-3" >
        <Content data={incomePieData} type="income" />
        <Content data={expenditurePieData} type="expenditure" />
      </div>
    </div>
  )
}
