import { iAccountChange, iAccountEdit, iAccountEnable } from "@/types/setting"
import request from "@/utils/common/request"

/**
 * 获取账号列表
 * @returns {Promise<data>}
 */
export async function apiAccountList() {
  const { data } = await request.get('/api/projectSetting/account')
  return data
}


/**
 * 设置账号密码
 * @param payload - 载荷
 */
export async function apiAccountChange(payload: iAccountChange) {
  const { data } = await request.post('/api/projectSetting/account/change', { id: payload.id, account: payload.ps_account, password: payload.ps_password })
  return data
}

/**
 * 新增/编辑账号
 * @param payload - 载荷
 */
export async function apiAccountEdit(type:string, payload: iAccountEdit) {
  const { data } = await request.post(`/api/projectSetting/account/${type === 'add' ? 'create' : 'save'}`, payload)
  return data
}

/**
 * 删除账号
 * @param id - 账号id
 */
export async function apiAccountDelete(id: string) {
  const { data } = await request.post('/api/projectSetting/account/delete', { id })
  return data
}

/**
 * 账号启用/禁用
 * @param id - 账号id
 * @param enable - 启用/禁用
 */
export async function apiAccountEnable(payload: iAccountEnable) {
  const { data } = await request.post('/api/projectSetting/account/enable', payload)
  return data
}


/**
 * 检索账号信息
 * @param name - 检索内容
 */
export async function apiAccountSearch(name: string) {
  const { data } = await request.get('/api/projectSetting/account/search', { name })
  return data
}

