import { iUserInfo } from '@/types/setting'
import consts from '@/utils/consts'
import { generatePsw } from '@/utils/util'
import { EyeInvisibleOutlined, EyeTwoTone } from '@ant-design/icons'
import { Form, Input, message, Modal } from 'antd'
import React, { useEffect, useState } from 'react'
import { apiAccountChange } from '../api'
import styles from '../index.module.scss'
import StrengthMeter from '@/components/StrengthMeter'
interface iPswModalProps {
  visible: boolean
  onCancel: () => void
  userInfo: iUserInfo
}
interface iValues {
  id: string
  ps_account: string
  ps_password: string
}
const PswModal: React.FC<iPswModalProps> = ({ visible, onCancel, userInfo: { id, account } }) => {
  const [ loading, setLoading ] = useState(false)
  const [ form ] = Form.useForm()
  const onCreate = async (values: iValues) => {
    setLoading(true)
    const { code = -1 } = await apiAccountChange(values)
    if (code === consts.RET_CODE.SUCCESS) {
      message.success('修改成功')
      onCancel()
    }
    setLoading(false)
  }
  useEffect(() => {
    form.setFieldsValue({ id, ps_account: account })
  }, [ visible ])


  return (
    <div>
      <Modal
        getContainer={false}
        visible={visible}
        title="修改账号/密码"
        okText="提交修改"
        cancelText="关闭"
        confirmLoading={loading}
        onCancel={onCancel}
        onOk={() => {
          form.validateFields().then((values: any) => {
            form.resetFields()
            onCreate(values)
          })
        }}
      >

        <Form
          form={form}
          layout="vertical"
          className={styles.FormContent}
        >
          <Form.Item name="id" hidden>
            <Input />
          </Form.Item>
          <Form.Item name="ps_account" label="登录账号" rules={[ { required: true, message: '请输入账号' } ]}>
            <Input />
          </Form.Item>
          <Form.Item name="ps_password" label="登录密码" rules={[ { required: true, message: '请输入登录密码' }, () => ({
            validator(_, value) {
              if (value) {
                if (/(?=.*[0-9])(?=.*[a-zA-Z]).{6,30}/.test(value)) {
                  return Promise.resolve()
                }
                return Promise.reject('密码必须带有字母与数字的组合且大于6位')
              }
              return Promise.resolve()
            }
          }) ]}>
            <StrengthMeter />

          </Form.Item>
        </Form>
      </Modal>
    </div>
  )
}

export default PswModal
