import request from '@/utils/common/request'

/**
 * 获取标段账号列表
 * @param id 标段id
 */
export async function apiGetSettingAccount(id: string) {
  const { data } = await request.get('/api/projectSetting/bid/account', { bidsectionId: id })
  return data
}

/**
 * 添加成员账号
 * @param bidsectionId 标段id
 * @param accountId 账号id
 */
export async function apiCreateBidAccount(bidsectionId: string, accountId: string) {
  const { data } = await request.post('/api/projectSetting/bid/account/create', { bidsectionId, accountId })
  return data
}

/**
 * 设置成员权限
 * @param payload 权限
 * @param accountId 账号id
 * @param bidsectionId 标段id
 */
export async function apiUpdateBidAccountAuth(payload: {[key: string]: string[]}, accountId: string, bidsectionId: string) {
  const newPayload = {}
  for (const key in payload) {
    if (Object.prototype.hasOwnProperty.call(payload, key)) {
      const permissions = payload[key]
      permissions.forEach(item => {
        newPayload[key + toHumpWord(item)] = 1
      })
    }
  }
  const { data } = await request.post('/api/projectSetting/bid/account/auth', { ...newPayload, accountId, bidsectionId })
  return data
}

/** 将单词开头装换为大写 */
function toHumpWord(str: string) {
  return str.toLowerCase().replace(/( |^)[a-z]/g, L => L.toUpperCase())
}

/**
 * 移除标段成员账号
 * @param bidsectionId 标段id
 * @param accountId 账号id
 */
export async function apiDelBidAccount(bidsectionId: string, accountId: string) {
  const { data } = await request.del('/api/projectSetting/bid/account', { bidsectionId, accountId })
  return data
}
