import { GroupItem } from '@/pages/Quality/Content/Info/Detail/components/AuditContent'
import { ZhButton, ZhDangerButton } from '@/components/Button'
import Header from '@/components/Header'
import Slot from '@/components/Header/slot'
import SvgIcon from '@/components/SvgIcon'
import { userStore } from '@/store/mobx'
import { iAccountGroupItem, iPermissionData, iUserInfo } from '@/types/setting'
import { getUserGroup } from '@/utils/common/user'
import consts from '@/utils/consts'
import { Button, Input, message, Popover, Table } from 'antd'
import { ColumnsType } from 'antd/lib/table'
import { observer } from 'mobx-react'
import React, { useState, useEffect, ChangeEvent } from 'react'
import { RouteComponentProps } from 'react-router'
import { apiCreateBidAccount, apiDelBidAccount, apiGetSettingAccount, apiUpdateBidAccountAuth } from './api'
import PermissionModal from './modal'
import './index.scss'
import { Store } from 'antd/lib/form/interface'
interface iPopoverState {
  visible: boolean
  searchValue: string
}

interface PermissionType {
  access: number
  add: number
  delete: number
}

interface iTableDataState extends iUserInfo {
  contractPermission: string
  qualityPermission: string
  safePermission: string
}

interface iPermissionModalState {
  visible: boolean
  loading: boolean
  permissionObj: {
    contract: string
    safe: string
    quality: string
  }
  id: string
}
interface iState {
  loading: boolean
  groups: iAccountGroupItem[]
  popover: iPopoverState
  dataSource: iTableDataState[]
  permissionModal: iPermissionModalState
}

const Member: React.FC<RouteComponentProps> = props => {
  const { id = '', name = '' }: { id: string; name: string } = props.location.state as any
  const [ state, setState ] = useState<iState>({
    groups: [],
    loading: false,
    popover: { visible: false, searchValue: '' },
    dataSource: [],
    permissionModal: {
      visible: false,
      loading: false,
      permissionObj: {
        contract: '',
        safe: '',
        quality: ''
      },
      id: ''
    }
  })
  useEffect(() => {
    state.popover.visible && initGroupList()
  }, [ state.popover.visible ])

  useEffect(() => {
    if (!userStore.groupList.length) {
      userStore.getGroupList()
    }
    initData()
  }, [])

  const initData = async () => {
    setState({ ...state, loading: true })
    const { code = -1, data } = await apiGetSettingAccount(id)
    if (code === consts.RET_CODE.SUCCESS) {
      setState({ ...state, loading: false, dataSource: data, permissionModal: { ...state.permissionModal, visible: false, loading: false },  popover: { ...state.popover, visible: false, searchValue: '' } })
    }
  }

  const openPermissionModal = (id: string, permissionObj: { contract: string; safe: string; quality: string;  }) => {
    setState({ ...state, permissionModal: { ...state.permissionModal, visible: true, permissionObj, id } })
  }

  const deleteSettingMenmber = async (bid: string, id: string) => {
    const { code = -1 } = await apiDelBidAccount(bid, id)
    if (code === consts.RET_CODE.SUCCESS) {
      const newData = state.dataSource.filter(item => item.id !== id)
      setState({ ...state, dataSource: newData })
    }
  }
  const renderPermissionText = (permission: PermissionType | undefined): React.ReactNode => {
    if (permission) {
      let textNode = ''
      for (const key in permission) {
        if (Object.prototype.hasOwnProperty.call(permission, key)) {
          const perm = permission[key]
          switch (key) {
            case 'access':
              perm && (textNode += '<span>查看所有</span>')
              break
            case 'add':
              perm && (textNode += '<span>创建</span>')
              break
            case 'delete':
              perm && (textNode += '<span>删除</span>')
              break
            default:
              break
          }
        }
      }
      return <div className="permission-text" dangerouslySetInnerHTML={{ __html: textNode }} />
    }
  }
  const columns: ColumnsType<iTableDataState> = [
    {
      title: '成员名称',
      key: 'name',
      dataIndex: 'name',
      width: '17%'
    },
    {
      title: '合同管理权限',
      key: 'contractPermission',
      dataIndex: 'contractPermission',
      width: '22%',
      render: (text: string) => {
        const contractJson: PermissionType | undefined = text && JSON.parse(text)
        return renderPermissionText(contractJson)
      }
    },
    {
      title: '安全管理权限',
      key: 'safePermission',
      dataIndex: 'safePermission',
      width: '22%',
      render: (text: string) => {
        const safeJson: PermissionType | undefined = text && JSON.parse(text)
        return renderPermissionText(safeJson)
      }
    },
    {
      title: '质量管理权限',
      key: 'qualityPermission',
      dataIndex: 'qualityPermission',
      width: '22%',
      render: (text: string) => {
        const qualityJson: PermissionType | undefined = text && JSON.parse(text)
        return renderPermissionText(qualityJson)
      }
    },
    {
      title: '操作',
      dataIndex: 'opreate',
      key: 'opreate',
      width: '17%',
      // eslint-disable-next-line react/display-name
      render: (_: any, record: iTableDataState) => {
        const { contractPermission: contract = '', qualityPermission: quality = '', safePermission: safe = '' } = record
        return (
          <div className="pi-flex">
            <ZhButton size="small" className="pi-mg-right-5" onClick={() => openPermissionModal(record.id, { contract,safe, quality })}>
              权限
            </ZhButton>
            <ZhDangerButton size="small" danger onClick={() => deleteSettingMenmber(id, record.id)}>
              移除
            </ZhDangerButton>
          </div>
        )
      }
    }
  ]
  const initGroupList = async (serach?: string) => {
    const data = await getUserGroup({ name: serach, hasOwner: false })
    setState({ ...state, groups: data })
  }

  const search = (value: string) => {
    if (value != state.popover.searchValue) {
      setState({ ...state, popover: { ...state.popover, searchValue: value } })
      initGroupList(value)
    }
  }

  const change = (e: ChangeEvent) => {

    e.persist()
    const target = e.target as HTMLTextAreaElement
    if (!target.value) {
      initGroupList()
    }
  }
  const calcPermissionData = () => {
    const permissionArr: iPermissionData[] = []
    if (state.permissionModal.visible) {
      for (const key in state.permissionModal.permissionObj) {
        if (Object.prototype.hasOwnProperty.call(state.permissionModal.permissionObj, key)) {
          const modalData: iPermissionData = { label: '', permissions: [], type: key }
          switch (key) {
            case 'contract':
              modalData.label = '合同管理'
              break
            case 'safe':
              modalData.label = '安全巡检'
              break
            case 'quality':
              modalData.label = '质量巡检'
              break
            default:
              break
          }
          const permission: PermissionType | undefined = state.permissionModal.permissionObj[key] && JSON.parse(state.permissionModal.permissionObj[key])
          if (permission) {
            for (const type in permission) {
              if (Object.prototype.hasOwnProperty.call(permission, type)) {
                const perm = permission[type]
                if (perm) {
                  modalData.permissions.push(type)
                }
              }
            }
          }
          permissionArr.push(modalData)
        }
      }
    }
    return { permissionArr, visible: state.permissionModal.visible, loading: state.permissionModal.loading }
  }

  const itemSelectHandler = async (item: iUserInfo) => {
    const { code = -1 } = await apiCreateBidAccount(id, item.id)
    if (code === consts.RET_CODE.SUCCESS) {
      await initData()
    }
  }

  const handleVisibleChange = (visible: boolean) => {
    setState({ ...state, popover: { ...state.popover, visible } })
  }

  const showPopover = () => {
    setState({ ...state, popover: { ...state.popover, visible: true } })
  }

  const onModalConfirm = async (values: Store) => {
    setState({ ...state, permissionModal: { ...state.permissionModal, loading: true } })
    const { code = -1 } = await apiUpdateBidAccountAuth(values, state.permissionModal.id, id)
    if (code === consts.RET_CODE.SUCCESS) {
      initData()
      return message.success('成员权限更新成功')
    }
    setState({ ...state, permissionModal: { ...state.permissionModal, loading: false } })
    return message.error('更新失败，请重试')
  }

  const onModalCancel = () => {
    setState({ ...state, permissionModal: { ...state.permissionModal, visible: false } })
  }
  return (
    <div className="wrap-contaniner">
      <Header title={`${name} 成员管理`}>
        <Slot position="right">
          <Popover
            title={<Input.Search size="small" placeholder="姓名/手机 检索" onSearch={search} onChange={e => change(e)} />}
            content={state.groups.map(item => (
              <GroupItem {...item} key={item.value} onSelect={(item: iUserInfo) => itemSelectHandler(item)} />
            ))}
            overlayClassName="popover-card"
            trigger="click"
            visible={state.popover.visible}
            onVisibleChange={handleVisibleChange}
            placement="bottomRight">
            <Button type="primary" size="small" onClick={showPopover}>
              <span>添加成员</span>
              <SvgIcon type="xxh-caret-down" />
            </Button>
          </Popover>
        </Slot>
      </Header>
      <div className="wrap-content">
        <Table<iTableDataState>
          loading={state.loading}
          dataSource={state.dataSource}
          columns={columns}
          rowKey={record => record.id}
          pagination={{ size: 'small' }}
          bordered />
      </div>
      <PermissionModal data={calcPermissionData()} onCreate={onModalConfirm} onCancel={onModalCancel} />
    </div>
  )
}

export default observer(Member)
