import { ZhCloseButton } from '@/components/Button'
import { iPermissionData } from '@/types/setting'
import { Button, Checkbox, Form, Modal, Table } from 'antd'
import { CheckboxOptionType } from 'antd/lib/checkbox'
import { Store } from 'antd/lib/form/interface'
import { ColumnsType } from 'antd/lib/table'
import React, { memo, useEffect } from 'react'

interface iPermissionDataProps {
  permissionArr: iPermissionData[]
  visible: boolean
  loading: boolean
}
interface iPermissionSettingProps {
  onCreate: (values: Store) => void
  onCancel: () => void
  data: iPermissionDataProps
}
const PermissionSettingModal: React.FC<iPermissionSettingProps> = ({ onCreate, onCancel, data: { permissionArr, visible, loading } }) => {
  const [ form ] = Form.useForm()
  useEffect(() => {
    if (visible) {
      console.log(permissionArr)

      permissionArr.forEach(item => {
        form.setFieldsValue({ [item.type]: item.permissions })
      })
    }
  }, [ visible ])
  const checkboxOptions: CheckboxOptionType[] = [
    { label: '查看所有', value: 'access' },
    { label: '创建、编辑', value: 'add' },
    { label: '删除', value: 'delete' }
  ]
  const columns: ColumnsType<iPermissionData> = [
    {
      title: '栏目',
      dataIndex: 'label',
      width: '20%',
      align: 'center'
    },
    {
      title: '权限',
      dataIndex: 'permissionArr',
      width: '80%',
      // eslint-disable-next-line react/display-name
      render: (_, record) => {
        return (
          <Form.Item key={record.type} name={record.type}>
            <Checkbox.Group options={checkboxOptions} />
          </Form.Item>
        )
      }
    }
  ]
  return (
    <Modal
      title="权限设置"
      visible={visible}
      onCancel={onCancel}
      getContainer={false}
      footer={
        <div className="pi-justify-end">
          <ZhCloseButton size="small" onClick={onCancel} className="pi-mg-right-5">
            取消
          </ZhCloseButton>
          <Button
            size="small"
            type="primary"
            loading={loading}
            onClick={() => {
              form
                .validateFields()
                .then(values => {
                  onCreate(values)
                })
                .catch(err => {
                  console.log(err)
                })
            }}>
            确认修改
          </Button>
        </div>
      }>
      <Form form={form}>
        <Table<iPermissionData> dataSource={permissionArr} columns={columns} rowKey={record => record.label} pagination={false} bordered />
      </Form>
    </Modal>
  )
}

export default memo(PermissionSettingModal)
