import { userStore } from '@/store/mobx'
import { apiExternalAuthLogin } from '@/utils/common/api'
import consts from '@/utils/consts'
import history from '@/utils/history'
import { message } from 'antd'
import React, { useState, useEffect } from 'react'
import cycling from '../../assets/img/svg_cycling.png'
import wrong from '../../assets/img/svg_wrong.png'
import './index.less'

enum authStatus {
  success = 0,
  fail = -1,
  wait = 2,
  disable = 3
}

const PreAuth = () => {
  const [ state, setState ] = useState({
    status: authStatus.wait,
    redirect: ''
  })
  useEffect(() => {
    const token = window.location.search.split('=')[1]
    async function authLogin() {
      const { code = -1, data } = await apiExternalAuthLogin(token)
      if (code === consts.RET_CODE.SUCCESS) {
        setState({ ...state, status: authStatus.success })
        userStore.updateUserInfo(data)
        userStore.getProjectInfo()
        setTimeout(() => {
          history.replace('/console/dashboard')
        }, 250)
      } else if( code === authStatus.fail) {
        setState({ ...state, status: code, redirect: data.redirect })
      } else if(code === authStatus.disable){
        message.error('该账号已被停用')
        setState({ ...state, status: code })
      }
    }
    authLogin()
  }, [])

  return (
    <div className='pre-auth-container'>
      <img src={state.status === authStatus.fail ? wrong : cycling} alt="" />
      {
        state.status === authStatus.wait ? <div className='pre-auth-progress'>
          <div className='pre-auth-loading' />
        </div> : null
      }

      <div className='pre-auth-status'>
        {
          state.status === authStatus.wait ? <span>
            正在进入...
          </span> : null
        }
        {
          state.status === authStatus.fail ? <><span>请返回计量支付并</span>
            <span className='link' onClick={() => window.location.href = state.redirect}>重新进入</span></> : null
        }
        {
          state.status === authStatus.disable ? <span>请联系「项目管理系统」管理员，开启账号后再进入</span> : null
        }
      </div>
    </div>
  )
}

export default PreAuth
