import { iRulePayload } from "@/types/rule"
import { iCreateSafe } from "@/types/safe"
import request from "@/utils/common/request"

/**
 * 获取当前标段的安全巡检列表
 * @param bidsectionId 标段id
 */
export async function apiSafeList(bidsectionId: string, pageNo: number, pageSize: number) {
  const { data } = await request.get('/api/safe', { bidsectionId, pageNo, pageSize })
  return data
}

/**
 * 创建新的安全巡检记录
 * @param payload 载荷
 */
export async function apiCreateSafe(payload: iCreateSafe) {
  const { data } = await request.post('/api/safe/add', payload)
  return data
}

/**
 * 获取当前的规则
 * @param bidsectionId 标段id
 */
export async function apiGetRule(bidsectionId: string) {
  const { data } = await request.get('/api/rule', { bidsectionId })
  return data
}

/**
 * 提交编号规则设置
 * @param payload 载荷
 */
export async function apiSaveRule(payload: iRulePayload) {
  const newValue = payload.rule.reduce((prev, curr) => {
    prev[curr.type] = curr.value
    return prev
  }, {})
  const { data } = await request.post('/api/rule', { ...payload, rule: JSON.stringify(newValue) })
  return data
}

