/**路由配置信息 */

import AsyncModuleLoader from "@/components/AsyncModuleLoader/index"
import { RouteModel } from '@/types/router'
export const routeConfig: RouteModel[] = [
  {
    path: '/',
    redirect: '/console/dashboard'
  },
  {
    path: '/login',
    component: AsyncModuleLoader(() => import('@/pages/Login')),
    meta: {
      title: '登录'
    }
  },
  {
    path: '/auth',
    component: AsyncModuleLoader(() => import('@/pages/PreAuth')),
    meta: {
      title: '正在授权'
    }
  },
  {
    path: '/console',
    component: AsyncModuleLoader(() => import('@/layout/NavSide')),
    auth: [ 'USER', 'ADMIN' ],
    childRoutes: [
      {
        path: 'dashboard',
        component: AsyncModuleLoader(() => import('@/pages/Dashboard')),
        auth: [ 'USER', 'ADMIN' ],
        defaultChildRoute: true, //是否作为默认子路由
        meta: {
          icon: 'xxh-chalkboard',
          title: '待办事项',
          isTop: true,
          sort: 1
        }
      },
      {
        path: 'contract',
        component: AsyncModuleLoader(() => import('@/pages/Contract')),
        auth: [ 'USER', 'ADMIN' ],
        meta: {
          icon: 'xxh-book-open',
          title: '合同管理',
          isTop: true,
          sort: 2
        },
        childRoutes: [
          {
            path: 'list',
            component: AsyncModuleLoader(() => import('@/pages/Contract/List')),
            defaultChildRoute: true,
            auth: [ 'USER', 'ADMIN' ],
            meta: {
              noCache: true
            }
          },
          {
            path: 'content',
            component: AsyncModuleLoader(() => import('@/pages/Contract/Content')),
            auth: [ 'USER', 'ADMIN' ],
            childRoutes: [
              {
                path: 'summary',
                component: AsyncModuleLoader(() => import('@/pages/Contract/Content/Summary')),
                defaultChildRoute: true,
                auth: [ 'USER', 'ADMIN' ],
                meta: {
                  title: '合同概况'
                }
              },
              {
                path: 'income',
                component: AsyncModuleLoader(() => import('@/pages/Contract/Content/Income')),
                auth: [ 'USER', 'ADMIN' ],
                meta: {
                  title: '收入合同'
                }
              },
              {
                path: 'spending',
                component: AsyncModuleLoader(() => import('@/pages/Contract/Content/Spending')),
                auth: [ 'USER', 'ADMIN' ],
                meta: {
                  title: '支出合同'
                }
              }
            ]
          }
        ]
      },
      {
        path: 'safe',
        component: AsyncModuleLoader(() => import('@/pages/Safe')),
        auth: [ 'USER', 'ADMIN' ],
        meta: {
          icon: 'xxh-users-cog',
          title: '安全巡检',
          isTop: true,
          sort: 3
        },
        childRoutes:[
          {
            path: 'list',
            component: AsyncModuleLoader(() => import('@/pages/Safe/List')),
            defaultChildRoute: true,
            auth: [ 'USER', 'ADMIN' ],
            meta: {
              noCache: true
            }
          },
          {
            path: 'content',
            component: AsyncModuleLoader(() => import('@/pages/Safe/Content')),
            auth: [ 'USER', 'ADMIN' ],
            childRoutes: [
              {
                path: 'summary',
                component: AsyncModuleLoader(() => import('@/pages/Safe/Content/Info/Summary')),
                auth: [ 'USER', 'ADMIN' ],
                defaultChildRoute: true,
                meta: {
                  icon: 'xxh-chart-pie',
                  title: '巡检概况'
                }
              },
              {
                path: "detail",
                component: AsyncModuleLoader(() => import('@/pages/Safe/Content/Info')),
                auth: [ 'USER', 'ADMIN' ],
                meta: {
                  title: '安全巡检'
                },
                childRoutes: [
                  {
                    path: 'list',
                    component: AsyncModuleLoader(() => import('@/pages/Safe/Content/List')),
                    auth: [ 'USER', 'ADMIN' ],
                    defaultChildRoute: true,
                    meta: {
                      noCache: true
                    }
                  },
                  {
                    path: 'info',
                    component: AsyncModuleLoader(() => import('@/pages/Safe/Content/Info/Detail')),
                    auth: [ 'USER', 'ADMIN' ]
                  }
                ]
              }
            ]
          }
        ]
      },
      {
        path: 'quality',
        component: AsyncModuleLoader(() => import('@/pages/Quality')),
        auth: [ 'USER', 'ADMIN' ],
        meta: {
          icon: 'xxh-toolbox',
          title: '质量巡检',
          isTop: true,
          sort: 4
        },
        childRoutes:[
          {
            path: 'list',
            component: AsyncModuleLoader(() => import('@/pages/Quality/List')),
            defaultChildRoute: true,
            auth: [ 'USER', 'ADMIN' ],
            meta: {
              noCache: true
            }
          },
          {
            path: 'content',
            component: AsyncModuleLoader(() => import('@/pages/Quality/Content')),
            auth: [ 'USER', 'ADMIN' ],
            childRoutes: [
              {
                path: 'summary',
                component: AsyncModuleLoader(() => import('@/pages/Quality/Content/Info/Summary')),
                auth: [ 'USER', 'ADMIN' ],
                defaultChildRoute: true,
                meta: {
                  icon: 'xxh-chart-pie',
                  title: '巡检概况'
                }
              },
              {
                path: "detail",
                component: AsyncModuleLoader(() => import('@/pages/Quality/Content/Info')),
                auth: [ 'USER', 'ADMIN' ],
                meta: {
                  title: '质量巡检'
                },
                childRoutes: [
                  {
                    path: 'list',
                    component: AsyncModuleLoader(() => import('@/pages/Quality/Content/List')),
                    auth: [ 'USER', 'ADMIN' ],
                    defaultChildRoute: true
                  },
                  {
                    path: 'info',
                    component: AsyncModuleLoader(() => import('@/pages/Quality/Content/Info/Detail')),
                    auth: [ 'USER', 'ADMIN' ]
                  }
                ]
              }
            ]
          }
        ]
      },
      {
        path: 'management',
        component: AsyncModuleLoader(() => import('@/pages/Management')),
        auth: [ 'ADMIN' ],
        meta: {
          icon: 'xxh-cogs',
          title: '项目设置',
          isTop: false
        },
        childRoutes: [
          {
            path: 'info',
            defaultChildRoute: true,
            auth: [ 'ADMIN' ],
            component: AsyncModuleLoader(() => import('@/pages/Management/Info')),
            meta: {
              title: '项目信息'
            }
          },
          {
            path: 'setting',
            auth: [ 'ADMIN' ],
            component: AsyncModuleLoader(() => import('@/pages/Management/Setting')),
            meta: {
              title: '账号设置'
            }
          },
          {
            path: 'tender',
            auth: [ 'ADMIN' ],
            component: AsyncModuleLoader(() => import('@/pages/Management/Tender')),
            meta: {
              title: '标段管理'
            },
            childRoutes: [
              {
                path: 'list',
                defaultChildRoute: true,
                auth: [ 'ADMIN' ],
                component: AsyncModuleLoader(() => import('@/pages/Management/Tender/List'))
              },
              {
                path: 'member',
                auth: [ 'ADMIN' ],
                component: AsyncModuleLoader(() => import('@/pages/Management/Tender/Member'))
              }
            ]
          }
        ]
      },

      {
        path: 'account',
        component: AsyncModuleLoader(() => import('@/pages/Account')),
        auth: [ 'USER', 'ADMIN' ],
        childRoutes: [
          {
            path: 'info',
            defaultChildRoute: true,
            auth: [ 'USER', 'ADMIN' ],
            component:AsyncModuleLoader(() => import('@/pages/Account/Information')),
            meta: {
              title: '账号资料'
            }
          },
          {
            path: 'safe',
            auth: [ 'USER', 'ADMIN' ],
            component:AsyncModuleLoader(() => import('@/pages/Account/Safe')),
            meta: {
              title: '账号安全'
            }
          },
          {
            path: 'manual',
            auth: [ 'USER', 'ADMIN' ],
            component:AsyncModuleLoader(() => import('@/pages/Account/Manual')),
            meta: {
              title: '帮助中心'
            }
          }
        ]
      }
    ]
  }
]
