import { routeConfig } from '@/router/routes'
import { RouteModel } from "@/types/router"
import { combinationPath } from "@/utils/util"
import { action, observable } from "mobx"
//处理用户写在@/router/route.config.ts中的路由配置信息
function handelRouteConfig(routeConfig: RouteModel | RouteModel[]) {
    //创建path与title的映射关系，供面包屑和分页组件使用
    const pathNameMapping: Map<string, string> = new Map()
    //处理完成之后的配置信息
    const handledRouteConfig: RouteModel | RouteModel[] = JSON.parse(JSON.stringify(routeConfig))
    //各子菜单的默认路由
    const defaultRouteMapping: Map<string, string> = new Map()

    const doHandelRouteConfig = (routeItem: RouteModel | RouteModel[], parentRoute?: RouteModel) => {
        if (Array.isArray(routeItem)) {
            for (const route of routeItem) {
                doHandelRouteConfig(route)
            }
        } else {
            routeItem.path = combinationPath(parentRoute?.path, routeItem.path)
            const routeName = routeItem.meta?.title ? routeItem.meta.title : routeItem.path
            pathNameMapping.set(routeItem.path, routeName)

            if (routeItem.defaultChildRoute && parentRoute) {
                defaultRouteMapping.set(parentRoute.path, routeItem.path)
            }

            if (routeItem.childRoutes) {
                for (const route of routeItem.childRoutes) {
                    doHandelRouteConfig(route, routeItem)
                }
            }
        }

    }

    doHandelRouteConfig(handledRouteConfig)

    return {
        pathNameMapping,
        handledRouteConfig,
        defaultRouteMapping
    }

}

class RouterState {
    constructor() {
        const { pathNameMapping, handledRouteConfig, defaultRouteMapping } = handelRouteConfig(routeConfig)
        this.routeNameMapping = pathNameMapping
        this.handledRouteConfig = handledRouteConfig
        this.defaultRouteMapping = defaultRouteMapping
    }

    @observable routeNameMapping: Map<string, string> = new Map()
    @observable defaultRouteMapping: Map<string, string> = new Map()
    @observable handledRouteConfig: RouteModel | RouteModel[] = []
    @observable currentRoutePath!: string;

    @action setRouteNameMapping(key: string, value: string) {
        this.routeNameMapping.set(key, value)

    }

    @action setCurrentRoutePath(cpath: string) {
        this.currentRoutePath = cpath
    }

}

export default new RouterState()
