import { iPermission } from "@/types/setting"
import { apiGetPermission } from "@/utils/common/api"
import consts from "@/utils/consts"
import { storage } from "@/utils/util"
import { action, computed, observable } from "mobx"

interface iTenderState {
  bidsectionId: string
  name: string
}

interface AuthState {
  contract: iPermission
  quality: iPermission
  safe: iPermission
}
class Tender {

  @observable tender:iTenderState = {
    bidsectionId: '',
    name: ''
  }
  @observable permission?: AuthState

  // 保存标段id、名称
  @action saveTenderInfo ({ bidsectionId, name }: {bidsectionId: string, name: string}) {
    this.tender = { bidsectionId, name }
    storage.set('tenderInfo', { bidsectionId, name })
  }

  // 从本地存储中获取标段信息
  @action cloneTenderFromStorage() {
    const tender = storage.get('tenderInfo')
    tender && (this.tender = tender)
  }

  // 保存标段权限
  @action async saveTenderPermission() {
    const { code = -1, data } = await apiGetPermission(this.bid)
    const permissionObj = {} as AuthState
    if (code === consts.RET_CODE.SUCCESS) {
      for (const key in data) {
        if (Object.prototype.hasOwnProperty.call(data, key)) {
          const permission = data[key] as string
          permissionObj[key] = JSON.parse(permission)
        }
      }
    }
    this.permission = permissionObj
  }

  @computed get bid() {
    if (!this.tender.bidsectionId) {
      const tenderInfo = storage.get('tenderInfo')

      tenderInfo && (this.tender = tenderInfo)

      return tenderInfo && tenderInfo.bidsectionId ? tenderInfo.bidsectionId : ''
    }
    return this.tender.bidsectionId
  }

  @computed get bidsction_name() {
    if (!this.tender.bidsectionId) {
      const tenderInfo = storage.get('tenderInfo')
      this.tender = tenderInfo
      return tenderInfo.name
    }
    return this.tender.name
  }
}

export default new Tender()
