import { apiLogout } from '@/components/Menu/api'
import { apiLogin } from '@/pages/Login/api'
import { iFromValues } from '@/types/login'
import { ProjectInfo } from '@/types/project'
import { iGroup, iUserInfo } from '@/types/setting'
import { apiGetGroupList, apiProjectInfo, apiUserInfo } from '@/utils/common/api'
import { saveUserInfo } from '@/utils/common/user'
import consts from '@/utils/consts'
import history from '@/utils/history'
import { action, computed, observable } from 'mobx'

class UserState {
  initUserState = {
    account: '',
    accountGroup: 0,
    company: '',
    csrf: '',
    enable: 0,
    id: '',
    isAdmin: 0,
    mobile: '',
    name: '',
    password: '',
    position: '',
    projectId: '',
    role: '',
    telephone: ''
  }
  @observable loading: boolean = false

  @observable userInfo: iUserInfo = this.initUserState

  @observable permission: [] = []

  @observable showLeftSide: boolean = true

  @observable groupList:iGroup[] = []

  @observable projectInfo:ProjectInfo = { id: '', code: '', name: '',staffName: '', staffQq: '', staffPhone: '', staffTelephone: '' }

  @computed get isLogin() {
    return !!this.userInfo.id
  }
  @computed get role() {
    return this.userInfo.isAdmin ? 'ADMIN' : 'USER'
  }
  @computed get isAdmin() {
    return this.userInfo.isAdmin
  }

  @computed get projectName() {
    return this.projectInfo.name
  }

  @computed get menuBtnText() {
    return this.userInfo.name || this.userInfo.account
  }
  @action async login(values: iFromValues) {
    const { code = -1, data } = await apiLogin(values)
    if (code === consts.RET_CODE.SUCCESS) {
      await this.getProjectInfo()
      this.userInfo = data
    }
  }

  @action updateUserInfo(values: any) {
    this.userInfo = { ...this.userInfo, ...values }
    saveUserInfo(this.userInfo)
  }

  @action toggleLeftSide() {
    this.showLeftSide = !this.showLeftSide
  }

  @action async logout() {
    await apiLogout()
    this.userInfo = this.initUserState
    history.replace('/login')
  }

  @action async check(pathname?: string) {
    if (pathname && consts.ROUTES_WHILE.includes(pathname)) {
      return
    }
    if (!this.userInfo?.id) {
      this.toggleLoading()
      await this.getUserInfo()
      this.toggleLoading()
    }
  }

  @action async getUserInfo() {
    const { code = -1, data } = await apiUserInfo()
    if (code === consts.RET_CODE.SUCCESS) {
      this.userInfo = data
    } else {
      history.replace('/login')
    }
  }

  @action toggleLoading() {
    this.loading = !this.loading
  }

  @action getGroupList() {
    apiGetGroupList().then(({ code = -1, data = [] }) => {
      if (code === consts.RET_CODE.SUCCESS) {
        const newData = []
        for (const key in data) {
          if (Object.prototype.hasOwnProperty.call(data, key)) {
            const value: string = data[key]
            newData.push({ key: parseInt(key), value })
          }
        }
        this.groupList = newData
      }
    })
  }

  @action getProjectInfo() {
    apiProjectInfo().then(({ code = -1, data }) => {
      if (code === consts.RET_CODE.SUCCESS) {
        this.projectInfo = data
      }
    })
  }
}

export default new UserState()
