import { iFile } from "@/types/file"
import request from "./request"

/**
 * 保存文件信息
 * @param fileList - 附件数组
 * @param dataType - 类型
 * @param dataId - 数据id
 */
export async function apiSaveFileInfo(fileList: iFile[], dataType: number, dataId: string) {
  const { data } = await request.post('/api/file', { fileList, dataType, dataId })
  return data
}

/**
 * 删除附件
 * @param id 附件id
 */
export async function apiDelFile(id:string) {
  const { data } = await request.del('/api/file', { id })
  return data
}

/**
 * 根据类型获取附件列表
 * @param dataType - 类型
 * @param dataId - 数据id
 */
export async function apiGetFileList(dataType: number, dataId: string, pageNo: number, pageSize: number) {
  const { data } = await request.get('/api/file', { dataType, dataId, pageNo, pageSize })
  return data
}

// 获取签名
export async function getSignature() {
  const { data } = await request.get('/api/oss/signature')
  return data
}

/** 获取账号分组信息 */
export async function apiGetGroupList() {
  const { data } = await request.get("/api/projectAccount/group")
  return data
}

/** 获取账号列表(检索标段下的成员账号) */
export async function apiGetAccountWithSearch(bidsectionId?: string, name?: string) {
  const url = bidsectionId ? '/api/projectSetting/bid/account' : '/api/projectAccount/search'
  const payload: any = {}
  if (bidsectionId) {
    payload.bidsectionId = bidsectionId
  }
  if (name) {
    payload.name = name
  }
  const { data } = await request.get(url, payload)
  return data
}


/** 获取权限列表 */
export async function apiGetPermissionWithBid(bidsectionId: string) {
  const { data } = await request.get('', { bidsectionId })
  return data
}

/** 获取登录项目信息 */
export async function apiProjectInfo() {
  const { data } = await request.get('/api/project')
  return data
}

/** 获取当前标段下的当前用户权限 */
export async function apiGetPermission(bidsectionId: string) {
  const { data } = await request.get('/api/projectSetting/permission', { bidsectionId })
  return data
}

/** 获取合同树 */
export async function apiContractList(type: number) {
  const { data } = await request.get('/api/contract/folder', { bidsectionType: type })
  return data
}

/**
 * 自动编号
 * @param bidsectionId 标段id
 * @param type 规则类型
 */
export async function apiAutoCode(bidsectionId: string, type: string) {
  const { data } = await request.post("/api/rule/auto", { bidsectionId, type })
  return data
}

/**
 * 获取项目节(不包括合同)
 * @param bidsectionId 标段id
 * @param treeType 树类型
 */
export async function apiContractSection(bidsectionId: string, treeType: number) {
  const { data } = await request.get('/api/contract/section/not', { bidsectionId, treeType })
  return data
}

/**
 * 计量-授权登录
 * @param token 令牌
 */
export async function apiExternalAuthLogin(token: string) {
  const { data } = await request.post('/api/external/jl/auth/login', { token })
  return data
}

/**
 * 校验计量项目
 */
export async function validJLProject() {
  const { data } = await request.post('/api/dashboard/project/exist')
  return data
}

/** 获取用户信息 */
export async function apiUserInfo() {
  const { data } = await request.get('/api/projectAccount/account')
  return data
}